==> webgui_7.9.27.orig.tar.gz: WebGUI/lib/WebGUI/i18n/English/Asset_MapPoint.pm <==
package WebGUI::i18n::English::Asset_MapPoint;

use strict; 

our $I18N = { 
    'latitude label' => {
        message     => 'Latitude',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'latitude description' => {
        message     => 'The latitude of the point',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'longitude label' => {
        message     => 'Longitude',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'longitude description' => {
        message     => 'The longitude of the point',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'website label' => {
        message     => 'Website URL',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'website description' => {
        message     => 'A website URL',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'address1 label' => {
        message     => 'Address 1',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'address1 description' => {
        message     => 'The first line of the address',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'address2 label' => {
        message     => 'Address 2',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'address2 description' => {
        message     => 'The second line of the address',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'city label' => {
        message     => 'City',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'city description' => {
        message     => 'The city the point is in',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'state label' => {
        message     => 'State/Province',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'state description' => {
        message     => 'The state/province the point is in',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'zipCode label' => {
        message     => 'Zip/Postal Code',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'zipCode description' => {
        message     => 'The zip/postal code the point is in',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'country label' => {
        message     => 'Country',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'country description' => {
        message     => 'The country the point is in',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'phone label' => {
        message     => 'Phone',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'phone description' => {
        message     => 'The phone number of the location',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'fax label' => {
        message     => 'Fax',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'fax description' => {
        message     => 'The fax number of the location',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'email label' => {
        message     => 'E-mail',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'email description' => {
        message     => 'The e-mail address of the location',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'storageIdPhoto label' => {
        message     => 'Photo',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'storageIdPhoto description' => {
        message     => 'A photo of the location',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },

    'assetName' => {
        message     => "MapPoint",
        lastUpdated => 0,
        context     => "Name of this asset",
    },

    'edit template' => {
        message     => "MapPoint Edit Point Template",
        lastUpdated => 0,
        context     => "template variable section title",
    },

    'form_header' => {
        message     => "HTML code to start the edit form.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_footer' => {
        message     => "HTML code to end the edit form.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_submit' => {
        message     => "A button to submit the edit form.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_title' => {
        message     => "A text form element for entering the title.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_synopsis' => {
        message     => "A textarea form element for entering the synopsis.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_storageIdPhoto' => {
        message     => "A file form element for uploading a photo relating to the map point.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'currentPhoto' => {
        message     => "An image tag linking to any currently uploaded photo.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_website' => {
        message     => "A text field for entering in a URL related to the map point.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_address1' => {
        message     => "A text field for entering in one part of an address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_address2' => {
        message     => "A text field for entering in another part of an address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_address3' => {
        message     => "A text field for entering in the last past of an address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_city' => {
        message     => "A text field for entering in city part of the address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_region' => {
        message     => "A text field for entering in region, or state, part of the address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_zipCode' => {
        message     => "A text field for entering in the zip code part of the address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_country' => {
        message     => "A text field for entering in the country part of the address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_phone' => {
        message     => "A text field for entering in a phone number.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_fax' => {
        message     => "A text field for entering in a fax number.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_email' => {
        message     => "A text field for entering in an email address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'storageIdPhoto' => {
        message     => "The storage location for this MapPoint.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'website' => {
        message     => "The website for this MapPoint.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'address1' => {
        message     => "The first line of the address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'address2' => {
        message     => "The second line of the address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'address3' => {
        message     => "The third line of the address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'city' => {
        message     => "The city for this MapPoint.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'region' => {
        message     => "The region, or state or province, for this MapPoint.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'zipCode' => {
        message     => "The zip code for this MapPoint.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'country' => {
        message     => "The country for this MapPoint.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'phone' => {
        message     => "The phone number for this MapPoint.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'fax' => {
        message     => "The fax number for this MapPoint.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'email' => {
        message     => "The email address for this MapPoint.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'map point asset template variables' => {
        message     => "Map Point Asset Template Variables",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'latitude' => {
        message     => "The latitude of the MapPoint",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'longitude' => {
        message     => "The longitude of the MapPoint",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'userDefined1' => {
        message     => "The value of userDefined field 1.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'userDefined2' => {
        message     => "The value of userDefined field 2.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'userDefined3' => {
        message     => "The value of userDefined field 3.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'userDefined4' => {
        message     => "The value of userDefined field 4.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'userDefined5' => {
        message     => "The value of userDefined field 5.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'user defined variables' => {
        message     => "Unlike the Collaboration System, the Map Point does not provide predefined form fields for the userdefined variables.  Instead, create any kind of form field that you need and give the field the name of the userDefined variable that you want to use.  WebGUI will handle saving it.",
        lastUpdated => 0,
        context     => "template variable help",
    },

};

1;
#vim:ft=perl

==> webgui_7.10.29.orig.tar.gz: WebGUI/lib/WebGUI/i18n/English/Asset_MapPoint.pm <==
package WebGUI::i18n::English::Asset_MapPoint;

use strict; 

our $I18N = { 
    'latitude label' => {
        message     => 'Latitude',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'latitude description' => {
        message     => 'The latitude of the point',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'longitude label' => {
        message     => 'Longitude',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'longitude description' => {
        message     => 'The longitude of the point',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'website label' => {
        message     => 'Website URL',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'website description' => {
        message     => 'A website URL',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'address1 label' => {
        message     => 'Address 1',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'address1 description' => {
        message     => 'The first line of the address',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'address2 label' => {
        message     => 'Address 2',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'address2 description' => {
        message     => 'The second line of the address',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'city label' => {
        message     => 'City',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'city description' => {
        message     => 'The city the point is in',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'state label' => {
        message     => 'State/Province',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'state description' => {
        message     => 'The state/province the point is in',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'zipCode label' => {
        message     => 'Zip/Postal Code',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'zipCode description' => {
        message     => 'The zip/postal code the point is in',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'country label' => {
        message     => 'Country',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'country description' => {
        message     => 'The country the point is in',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'phone label' => {
        message     => 'Phone',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'phone description' => {
        message     => 'The phone number of the location',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'fax label' => {
        message     => 'Fax',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'fax description' => {
        message     => 'The fax number of the location',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'email label' => {
        message     => 'E-mail',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'email description' => {
        message     => 'The e-mail address of the location',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'storageIdPhoto label' => {
        message     => 'Photo',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'storageIdPhoto description' => {
        message     => 'A photo of the location',
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'isGeocoded label' => {
        message     => 'Automatically Position',
        lastUpdated => 0,
        context     => 'Label for asset property',
    },
    'isGeocoded description' => {
        message     => q{Choose whether or not this map point should be automatically positioned having it's latitude and longitude dynamically set based on the address.  Choosing "Yes" will make the point unable to be moved on the map.},
        lastUpdated => 0,
        context     => 'Description of asset property',
    },
    'assetName' => {
        message     => "MapPoint",
        lastUpdated => 0,
        context     => "Name of this asset",
    },

    'edit template' => {
        message     => "MapPoint Edit Point Template",
        lastUpdated => 0,
        context     => "template variable section title",
    },

    'form_header' => {
        message     => "HTML code to start the edit form.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_footer' => {
        message     => "HTML code to end the edit form.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_submit' => {
        message     => "A button to submit the edit form.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_title' => {
        message     => "A text form element for entering the title.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_synopsis' => {
        message     => "A textarea form element for entering the synopsis.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_storageIdPhoto' => {
        message     => "A file form element for uploading a photo relating to the map point.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'currentPhoto' => {
        message     => "An image tag linking to any currently uploaded photo.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_website' => {
        message     => "A text field for entering in a URL related to the map point.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_address1' => {
        message     => "A text field for entering in one part of an address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_address2' => {
        message     => "A text field for entering in another part of an address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_address3' => {
        message     => "A text field for entering in the last past of an address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_city' => {
        message     => "A text field for entering in city part of the address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_region' => {
        message     => "A text field for entering in region, or state, part of the address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_zipCode' => {
        message     => "A text field for entering in the zip code part of the address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_country' => {
        message     => "A text field for entering in the country part of the address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_phone' => {
        message     => "A text field for entering in a phone number.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_fax' => {
        message     => "A text field for entering in a fax number.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_email' => {
        message     => "A text field for entering in an email address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'storageIdPhoto' => {
        message     => "The storage location for this MapPoint.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'website' => {
        message     => "The website for this MapPoint.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'address1' => {
        message     => "The first line of the address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'address2' => {
        message     => "The second line of the address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'address3' => {
        message     => "The third line of the address.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'city' => {
        message     => "The city for this MapPoint.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'region' => {
        message     => "The region, or state or province, for this MapPoint.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'zipCode' => {
        message     => "The zip code for this MapPoint.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'country' => {
        message     => "The country for this MapPoint.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'phone' => {
        message     => "The phone number for this MapPoint.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'fax' => {
        message     => "The fax number for this MapPoint.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'email' => {
        message     => "The email address for this MapPoint.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'map point asset template variables' => {
        message     => "Map Point Asset Template Variables",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'latitude' => {
        message     => "The latitude of the MapPoint",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'longitude' => {
        message     => "The longitude of the MapPoint",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'userDefined1' => {
        message     => "The value of userDefined field 1.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'userDefined2' => {
        message     => "The value of userDefined field 2.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'userDefined3' => {
        message     => "The value of userDefined field 3.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'userDefined4' => {
        message     => "The value of userDefined field 4.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'userDefined5' => {
        message     => "The value of userDefined field 5.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'user defined variables' => {
        message     => "Unlike the Collaboration System, the Map Point does not provide predefined form fields for the userdefined variables.  Instead, create any kind of form field that you need and give the field the name of the userDefined variable that you want to use.  WebGUI will handle saving it.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_isHidden' => {
        message     => "A yes/no field indicating whether or not the Map Point should display in navigations.",
        lastUpdated => 0,
        context     => "template variable help",
    },

    'form_isGeocoded' => {
        message     => "A checkbox field indicating whether or not the Map Point should be automatically placed on the map based on it's address.",
        lastUpdated => 0,
        context     => "template variable help",
    },
};

1;
#vim:ft=perl
